function [C,z,eta,xi]=notch(Mn,a,omn,gamma,xig);
%
% function [C,z,eta,xi]=notch(Mn,aHF,omn,gamma,xig);
%
% Progetto di filtro Notch
%
% INPUT
% Mn: attenuazione di notch che si desidera alla pulsazione omn (Mn<1)
% aHF: attenuazione ad alta frequenza, a<=1 (default a=1)
% omn: pulsazione di notch (default omn=1)
% gamma>1: semibanda notch (indica la posizione della pulsazione a destra di omn, alla quale
%       il modulo del filtro vale -3dB: om_3dB = gamma*omn); default: gamma tale per cui xi=0.6;
%       (gamma viene preso in considerazione solo quando aHF=1)
% xig: opzionale, permette di fissare a piacere il valore di dello
%       smorzamento xi dei poli del filtro. Questo parametro viene preso in
%       considerazione solo quando aHF<1, oppure quando aHF=1 e Mn<1/sqrt(2).
%       valore di default xig=0.6;
%
% OUTPUT
% C: oggetto tf contenente il filtro notch:
%       C =  (s^2/z^2 +2*eta*s/z +1)/(s^2/z^2/a^2 +2*xi*s/z/a +1)
% z,eta,xi: parametri del filtro
%
% @ G. Calafiore, 2005
%

